---
title: Источники данных планирования
slug: типовые-erp-планирование/источники-данных-планирования
---

**Автор:** Сергей Омельчук
**Дата публикации:** 21.11.2018
**Источник:** [Koderline.ru](https://www.koderline.ru/expert/instruktsii/article-istochniki-planirovaniya-v-1s-upravlenie-torgovley-11-1s-kompleksnaya-avtomatizatsiya-2-ili-erp-2/)

---

## Введение

В конфигурациях 1С:УТ 11, 1С:КА 2 или 1С\:ERP 2 имеется подсистема планирования, в которой при построении планов уже могут использоваться готовые шаблоны источников планирования.
Данная статья научит, как можно добавлять в систему свои собственные дополнительные шаблоны источников планирования, когда требуется такая необходимость.

А также данная задача встречается в сборниках задач по подготовке на 1С:Специалист по конфигурированию торговых решений и может помочь при подготовке к экзамену.

Данный пример реализации рассмотрим в конфигурации 1С:УТ 11.

## Постановка задачи на примере регистра накопления Выручка и себестоимость продаж

Для примера рассмотрим создание нового шаблона схемы компоновки данных для источников планирования:

* Продажи по ценовой группе

Для анализа источником данных будут служить данные по продажам регистра накопления:

* Выручка и себестоимость продаж

В данной схеме реализовать возможность отбора по ценовой группе номенклатуры.

## Список шаблонов: источники данных планирования

В конфигурации 1С:УТ 11 в подсистеме планирования можем увидеть справочник «Источники данных планирования».
При создании нового элемента настройки мы можем увидеть уже готовые схемы компоновки данных:

![Список шаблонов источников данных](/istochniki-dannyh-planirovaniya/1.png)

Тут довольно обширный список схем компоновки данных, подходящих на большее количество случаев жизни.
Но мы добавим еще свой собственный — «Продажи по ценовой группе».

Нам необходимо определить, откуда заполняется данное поле выбора схемы компоновки данных в конфигураторе.

![Выбор шаблона схемы компоновки данных](/istochniki-dannyh-planirovaniya/2.png)

Данное поле выбора СКД заполняется в форме элемента справочника «ИсточникиДанныхПланирования» в обработчике «ПриСозданииНаСервере», где вызывается функция модуля менеджера получения шаблонов: `ШаблоныСхемыКомпановкиДанных()`.

Сами же шаблоны схемы компоновки являются макетами обработки «ИсточникиДанныхПланирования»:

![Макеты обработки ИсточникиДанныхПланирования](/istochniki-dannyh-planirovaniya/3.png)

Где как раз мы видим список типовых схем источников планирования, и тип макета у них «Схема компоновки данных».
Поэтому при добавлении новых шаблонов именно сюда необходимо добавлять новые схемы.

## Создание нового шаблона

Так как у нас будут использоваться данные по продажам, то за основу мы можем использовать типовую схему «ПродажиПредопределенный».
Скопируем ее и переименуем в «ПродажиЦеноваяГруппа» и зададим соответствующий синоним:

![Новый макет схемы «ПродажиЦеноваяГруппа»](/istochniki-dannyh-planirovaniya/4.png)

Далее откроем новую схему для редактирования.
В данной схеме компоновки данных мы воспользуемся заменой ТоварнаяКатегория на ЦеновуюГруппу:

![Изменение схемы – поле ЦеноваяГруппа](/istochniki-dannyh-planirovaniya/5.png)

В итоге получится следующий результат схемы компоновки данных, в которой теперь будет доступен отбор по ценовой группе:

![Схема с добавленным отбором по ЦеновойГруппе](/istochniki-dannyh-planirovaniya/6.png)

Далее сохраняем отредактированную схему компоновки данных.

> **Важно!**
> Далее можно было бы уже воспользоваться новой схемой, но когда мы открыли существующую схему компоновки данных и потом нажали в конструкторе запроса «ОК», то он исправил некоторые моменты, которые были сделаны для редактирования и подстановки других частей запроса.
> Обратим внимание и сравним с исходником взятой схемы «ПродажиПредопределенный»:

![Сравнение SQL-запросов в схемах](/istochniki-dannyh-planirovaniya/7.png)

На скрине видим, что конструктор запроса для в дальнейшем заменяемому параметру добавил скобки, которые будут вызывать ошибки (можете самостоятельно проверить, мы в нашем примере поправим сразу), поправим и удалим скобки в нашей схеме.

## Как проверить источники планирования

Начнем проверять созданный новый шаблон схемы источника планирования.
Создадим новый источник планирования, основные моменты: в выборе схемы компоновки данных появился выбор нашего созданного шаблона, а также если перейти в редактирование, то имеется возможность выбора поля отбора «Ценовая группа». Запишем новый источник.

![Новый источник с шаблоном «Ценовая группа»](/istochniki-dannyh-planirovaniya/8.png)

Далее создадим сценарий планирования с аналогичным названием «Продажи по ценовым группам», периодичность «Месяц»:

![Сценарий планирования «Продажи по ценовым группам»](/istochniki-dannyh-planirovaniya/9.png)

Во вкладке «Настройка создания» устанавливаем «Планы продаж по номенклатуре»:

![Настройка создания документа плана](/istochniki-dannyh-planirovaniya/10.png)

Записываем и настраиваем вид плана.
Для вида плана укажем наименование, используем для продаж и вариант заполнения расширенный по источникам:

![Вид плана с источником «Ценовая группа»](/istochniki-dannyh-planirovaniya/11.png)

Создадим теперь план продаж по номенклатуре и заполним его по нашему сценарию и виду плана:

![Документ плана продаж](/istochniki-dannyh-planirovaniya/12.png)

Выберем заполнение «Настроить правило и заполнить»:

![Настройка правила заполнения](/istochniki-dannyh-planirovaniya/13.png)

Источник заполнения подставляется автоматически.
Укажем период для анализа данных и нажмем «Заполнить»:

![Период анализа данных при заполнении](/istochniki-dannyh-planirovaniya/14.png)

Документ удачно заполнился:

![Результат заполнения документа](/istochniki-dannyh-planirovaniya/15.png)

Вот так продемонстрировали создание своих собственных шаблонов схем источников планирования.

Возможно, эта статья поможет кому-то подготовиться к сдаче экзамена, а кому-то — в реальных задачах бизнеса.
Ну а если не сможете реализовать сами, то обращайтесь — мы поможем вам с данной доработкой.
Тем более, что на примере видно, что мы это умеем.

---

**Специалист компании ООО «Кодерлайн»
Сергей Омельчук**
